/* -*- Mode:C; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Marco Guastella <vasta@ragnu.it>
 */

#include "config.h" 
#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>

void usage()
{
	fprintf(stdout,"Author:Guastella Marco alias vasta\nhome page:http://www.ragnu.it\ncontact:vasta@ragnu.it\nversion:%s\nlicence:GPL3\n",VERSION);
	fprintf(stderr,"usage:lupin {-v |-l|-n}\n");
	exit(EXIT_FAILURE);	
}

int main(int argc,char *argv[])
{
	int c;	
	if(argc != 2)
		usage();
	if((c=getopt(argc,argv,"vln"))!=-1)
	{
		switch(c)
		{		
			case 'v':fprintf(stdout,"0.2.3\n");
		       		     break;
			case 'l':fprintf(stdout,"-llupin ");
				     break;
			case 'n':fprintf(stdout,"3");
				      break;
			default: usage();
					break;
		}	
	}		
	exit(EXIT_SUCCESS);
	return 0;
}

